@@ -11,10 +11,6 @@
 
 #include <kdb.h>
 
-#ifndef ELEKTRA_WITHOUT_ITERATOR
-#include <kdbproposal.h> // TODO remove (for keyUnescapedName())
-#endif
-
 namespace kdb
 {
 
@@ -175,6 +171,9 @@ public:
 	typedef void (*func_t)();
 	inline func_t getFunc() const;
 
+	typedef ckdb::Key * (*callback_t) (ckdb::KeySet *ks, ckdb::Key *key, ckdb::Key *found, option_t options);
+	inline void setCallback(callback_t fct);
+
 	inline const void *getValue() const;
 	inline std::string getBinary() const;
 	inline ssize_t getBinarySize() const;
@@ -242,6 +241,8 @@ class NameIterator
 public:
 	typedef std::string value_type;
 	typedef std::string reference;
+	typedef std::string pointer; // STL typedef is required by SWIG
+	typedef int difference_type; // STL typedef is required by SWIG
 	typedef std::bidirectional_iterator_tag iterator_category;
 
 	NameIterator(Key const & k, bool last) :
@@ -331,6 +332,8 @@ class NameReverseIterator : private NameIterator
 public:
 	typedef std::string value_type;
 	typedef std::string reference;
+	typedef std::string pointer; // STL typedef is required by SWIG
+	typedef int difference_type; // STL typedef is required by SWIG
 	typedef std::bidirectional_iterator_tag iterator_category;
 
 	NameReverseIterator(Key const & k, bool last) :
@@ -714,18 +717,20 @@ Key* Key::operator-> ()
 }
 
 /**
- * Passes out the raw key pointer.
+ * Passes out the raw key pointer and resets internal key handle.
  *
  * \note that the ownership is moved outside.
  *
- * The key will stay empty.
+ * @retval 0 if no key is held (null pointer), no action is done then.
  */
 ckdb::Key* Key::release ()
 {
 	ckdb::Key* ret = key;
-	operator --();
-
-	key = 0;
+	if (key)
+	{
+		operator --();
+		key = 0;
+	}
 	return ret;
 }
 
@@ -746,17 +751,23 @@ ckdb::Key* Key::dup () const
  */
 inline Key::~Key ()
 {
-	del();
+	if (key)
+	{
+		del();
+	}
 }
 
 /**
  * @copydoc keyName
  *
+ * @throw KeyException if key is null
+ *
  * @note unlike in the C version, it is safe to change the returned
  * string.
  */
 inline std::string Key::getName() const
 {
+	if (!key) throw KeyException();
 	return std::string (ckdb::keyName(key));
 }
 
@@ -1191,6 +1202,9 @@ inline ssize_t Key::getStringSize() const
 inline Key::func_t Key::getFunc() const
 {
 	union {Key::func_t f; void* v;} conversation;
+#if __cplusplus > 199711L
+	static_assert(sizeof(conversation) == sizeof(func_t), "union does not have size of function pointer");
+#endif
 
 	if (ckdb::keyGetBinary(getKey(),
 			&conversation.v,
@@ -1200,6 +1214,19 @@ inline Key::func_t Key::getFunc() const
 	return conversation.f;
 }
 
+
+inline void Key::setCallback(callback_t fct)
+{
+	union {callback_t f; void* v;} conversation;
+#if __cplusplus > 199711L
+	static_assert(sizeof(conversation) == sizeof(callback_t), "union does not have size of function pointer");
+#endif
+
+	conversation.f = fct;
+	ckdb::keySetBinary(getKey(), &conversation.v, sizeof(conversation));
+}
+
+
 /**
  * @copydoc keySetString
  */
@@ -1600,12 +1627,18 @@ inline bool Key::isDirectBelow(const Key & k) const
  * If there are still references, the function will only
  * decrement the reference counter.
  *
+ * @retval -1 if no key is held (null pointer)
+ *
  * @copydoc keyDel
  */
 inline int Key::del ()
 {
-	operator --();
-	return ckdb::keyDel(key);
+	if (key)
+	{
+		operator --();
+		return ckdb::keyDel(key);
+	}
+	return -1;
 }
 
 
