@@ -25,7 +25,7 @@
  * See "OMG Language Mapping" if you want to map the types to another
  * programming language.
  *
- * This files defines mappings to C and C++11
+ * This files defines mappings to C89, C++03 and C++11
  * */
 
 #ifndef KDBTYPES_H
@@ -76,8 +76,10 @@ namespace kdb
 	using octet_t = uint8_t; // default: 0
 }
 #endif
-#else
-// for C
+#endif // for c++
+
+
+// for C (and C++)
 
 typedef unsigned char             kdb_boolean_t;
 typedef unsigned char             kdb_char_t;
@@ -122,10 +124,11 @@ typedef double                    kdb_double_t;
 
 #if defined(HAVE_SIZEOF_LONG_DOUBLE) && (SIZEOF_LONG_DOUBLE == 16)
 typedef long double               kdb_long_double_t;
-#elif defined(HAVE_SIZEOF_LONG_DOUBLE) && (SIZEOF_LONG_DOUBLE == 12) && defined(__i386__)
+#elif defined(HAVE_SIZEOF_LONG_DOUBLE) && (SIZEOF_LONG_DOUBLE == 12)
+// the long double data type represents an IEEE double-extended
+// floating-point number, which has an exponent of at least 15 bits in
+// length and a signed fraction of at least 64 bits
 typedef long double               kdb_long_double_t;
 #endif
 
 #endif
-
-#endif
