@@ -18,9 +18,9 @@
  *
  * This symbol is exported and used during mounting.
  *
- * @return 1 on success (Relative path)
- * @returns 0 on success (Absolute path)
- * @return -1 on a non-valid file
+ * @retval 1 on success (Relative path)
+ * @retval 0 on success (Absolute path)
+ * @retval -1 on a non-valid file
  */
 int ELEKTRA_PLUGIN_FUNCTION(resolver,checkFile)(const char* filename)
 {
@@ -105,22 +105,38 @@ static int elektraResolveSystemBuildin(resolverHandle *p)
 	return 1;
 }
 
+static void elektraResolveSystemXDGHelper(resolverHandle *p, const char *result)
+{
+	size_t configDirSize = elektraStrLen(result);
+	size_t pathSize = elektraStrLen(p->path);
+	size_t filenameSize = configDirSize
+		+ pathSize + sizeof("/") + 1;
+
+	elektraRealloc ((void*)&p->filename, filenameSize);
+	strcpy (p->filename, result);
+	strcat (p->filename, "/");
+	strcat (p->filename, p->path);
+}
+
 static int elektraResolveSystemXDG(resolverHandle *p,
 		Key *warningsKey)
 {
 	const char * configDir = getenv("XDG_CONFIG_DIRS");
+	const char *defaultDir = "/etc/xdg";
 
 	if (!configDir || !strcmp(configDir, ""))
 	{
-		configDir = "/etc/xdg";
+		elektraResolveSystemXDGHelper(p, defaultDir);
+		elektraResolveFinishByFilename(p);
+		return 1;
 	}
 
-	size_t pathSize = elektraStrLen(p->path);
 	char *saveptr = 0;
 	char *str = elektraStrDup(configDir);
 	char *result = strtok_r (str, ":", &saveptr);
 	struct stat buf;
 	int errnoSave = errno;
+	int success = 0;
 	while (result)
 	{
 		if (result[0] != '/')
@@ -131,17 +147,14 @@ static int elektraResolveSystemXDG(resolverHandle *p,
 				"not absolute (violates XDG specification) and thus "
 			 	"it was skipped: %s",
 				result);
+
+			result = strtok_r (0, ":", &saveptr);
 			continue;
 		}
 
-		size_t configDirSize = elektraStrLen(result);
+		success = 1; // at least once we got a valid path
 
-		size_t filenameSize = configDirSize
-			+ pathSize + sizeof("/") + 1;
-		elektraRealloc ((void*)&p->filename, filenameSize);
-		strcpy (p->filename, result);
-		strcat (p->filename, "/");
-		strcat (p->filename, p->path);
+		elektraResolveSystemXDGHelper(p, result);
 
 		if (stat(p->filename, &buf) == 0)
 		{
@@ -154,6 +167,11 @@ static int elektraResolveSystemXDG(resolverHandle *p,
 	elektraFree(str);
 	errno = errnoSave;
 
+	if (!success)
+	{
+		elektraResolveSystemXDGHelper(p, defaultDir);
+	}
+
 	elektraResolveFinishByFilename(p);
 	return 1;
 }
@@ -442,7 +460,8 @@ static int elektraResolveDir(resolverHandle *p, Key *warningsKey)
 	if (!cwd) return -1;
 
 	char *dn = elektraStrDup(cwd);
-
+	char *dnOrig = dn;
+	
 	while (true)
 	{
 		// now put together the filename
@@ -473,7 +492,7 @@ static int elektraResolveDir(resolverHandle *p, Key *warningsKey)
 	}
 
 	elektraFree(cwd);
-	elektraFree(dn);
+	elektraFree(dnOrig);
 	elektraResolveFinishByFilename(p);
 	return 1;
 }
