@@ -1,7 +1,7 @@
 #include "treeviewmodel.hpp"
 #include "guibasickeyset.hpp"
 #include <threewaymerge.hpp>
-#include <onesidemergeconfiguration.hpp>
+#include <automergeconfiguration.hpp>
 #include <mergeconflictstrategy.hpp>
 #include <automergestrategy.hpp>
 #include <onesidestrategy.hpp>
@@ -19,7 +19,9 @@ using namespace kdb;
 using namespace kdb::tools;
 using namespace kdb::tools::merging;
 
-TreeViewModel::TreeViewModel(QObject* parentModel)
+TreeViewModel::TreeViewModel(QObject* parentModel) :
+	m_root("/", KEY_END),
+	m_kdb(m_root)
 {
 	Q_UNUSED(parentModel);
 }
@@ -27,7 +29,10 @@ TreeViewModel::TreeViewModel(QObject* parentModel)
 TreeViewModel::TreeViewModel(const TreeViewModel& other)
 	: QAbstractListModel()
 {
-	m_model = other.m_model; // copy from other list
+	// copy from other
+	m_model = other.m_model;
+	m_root = other.m_root;
+	m_kdb = other.m_kdb;
 }
 
 int TreeViewModel::rowCount(const QModelIndex& parentIndex) const
@@ -119,12 +124,16 @@ bool TreeViewModel::setData(const QModelIndex& idx, const QVariant& modelData, i
 	{
 
 	case NameRole:
-		node->setName(modelData.toString());
-		node->setIsDirty(true);
+		if(node->getName() != modelData.toString()){
+			node->setName(modelData.toString());
+			node->setIsDirty(true);
+		}
 		break;
 
 	case ValueRole:
-		node->setValue(modelData);
+		if(node->getValue() != modelData){
+			node->setValue(modelData);
+		}
 		break;
 
 	case MetaValueRole:
@@ -439,7 +448,22 @@ void TreeViewModel::sink(ConfigNodePtr node, QStringList keys, const Key& key)
 	}
 }
 
-void TreeViewModel::populateModel(KeySet keySet)
+void TreeViewModel::populateModel()
+{
+	try
+	{
+		kdb::KeySet config;
+		m_kdb.get(config, m_root);
+		populateModel(config);
+	}
+	catch(kdb::KDBException const& e)
+	{
+		emit showMessage(QObject::tr("Error"), QObject::tr("Populating model failed, could not read from configuration."), e.what());
+		throw;
+	}
+}
+
+void TreeViewModel::populateModel(KeySet const & keySet)
 {
 	GUIBasicKeySet::setBasic(keySet);
 
@@ -488,7 +512,7 @@ void TreeViewModel::createNewNodes(KeySet keySet)
 
 	while (keySet.next())
 	{
-		Key k = keySet.current().dup();
+		Key k = keySet.current();
 		QStringList keys = getSplittedKeyname(k);
 		QString root = keys.takeFirst();
 
@@ -519,36 +543,28 @@ void TreeViewModel::append(ConfigNodePtr node)
 	insertRow(rowCount(), node);
 }
 
-void TreeViewModel::synchronize()
+namespace
 {
-	KeySet ours = collectCurrentKeySet();
-	KeySet theirs;
-	KeySet base = GUIBasicKeySet::basic();
-	KeySet resultKeys;
 
-	Key root("/", KEY_END);
+#if DEBUG && VERBOSE
+std::string printKey(Key const & k)
+{
+	std::string ret;
+	ret += k.getName();
 
-	KDB kdb;
+	if (ckdb::keyNeedSync(*k)) ret += "°";
 
-	try
+	if (!k.isBinary())
 	{
-		kdb.get(theirs, root);
-	}
-	catch (KDBException const& e)
-	{
-		emit showMessage(tr("Error"), tr("Synchronizing failed, could not read from configuration."), e.what());
-		return;
+		ret += "=";
+		ret += k.getString();
 	}
+	return ret;
+}
+#endif
 
-	ours = ours.cut(root);
-	theirs = theirs.cut(root);
-	base = base.cut(root);
-
-	ThreeWayMerge merger;
-
-	OneSideMergeConfiguration configuration(OURS);
-	configuration.configureMerger(merger);
-
+void printKeys(KeySet const & theirs ELEKTRA_UNUSED, KeySet const & base ELEKTRA_UNUSED, KeySet const & ours ELEKTRA_UNUSED)
+{
 #if DEBUG && VERBOSE
 	theirs.rewind();
 	base.rewind();
@@ -556,57 +572,121 @@ void TreeViewModel::synchronize()
 	{
 		Key t = theirs.next();
 		Key b = base.next();
-		std::cout << o.getName() << " " << ckdb::keyNeedSync(*o);
+		std::cout << printKey(o);;
 		std::cout << "\t";
-		!b.isValid() ? std::cout << "none" : std::cout << b.getName() << " " << ckdb::keyNeedSync(*b);
+		!b.isValid() ? std::cout << "none" : std::cout << printKey(b);
 		std::cout << "\t";
-		!t.isValid() ? std::cout << "none" : std::cout << t.getName() << " " << ckdb::keyNeedSync(*t);
+		!t.isValid() ? std::cout << "none" : std::cout << printKey(t);
 		std::cout << std::endl;
 	}
 #endif
+}
+
+QStringList getConflicts(KeySet const & conflictSet)
+{
+	QStringList conflicts;
+	conflictSet.rewind();
+	Key current;
+
+	while ((current = conflictSet.next()))
+	{
+		QString ourConflict = QString::fromStdString(current.getMeta<string>("conflict/operation/our"));
+		QString theirConflict = QString::fromStdString(current.getMeta<string>("conflict/operation/their"));
+
+		conflicts.append(QString::fromStdString(current.getName()));
+		conflicts.append("Ours: " + ourConflict + ", Theirs " + theirConflict);
+		conflicts.append("\n");
+	}
+	return conflicts;
+}
+
+KeySet handleConflict(KeySet & ours)
+{
+	Key root("/", KEY_END);
+	KeySet base = GUIBasicKeySet::basic();
+
+	ThreeWayMerge merger;
+
+	AutoMergeConfiguration configuration;
+	configuration.configureMerger(merger);
+
+	// get theirs config
+	KDB kdb;
+	KeySet theirs;
+	kdb.get(theirs, root);
+
+	printKeys(theirs, base, ours);
 
 	MergeResult result = merger.mergeKeySet(MergeTask(BaseMergeKeys(base, root),
-													  OurMergeKeys(ours, root),
-													  TheirMergeKeys (theirs, root),
-													  root));
+							  OurMergeKeys(ours, root),
+							  TheirMergeKeys (theirs, root),
+							  root));
+
 	if (!result.hasConflicts ())
 	{
-		resultKeys.append(result.getMergedKeys());
+		KeySet resultKeys = result.getMergedKeys();
+
+		// 3-way merging allowed use to succeed anyway
+		// store the base for next time:
+		GUIBasicKeySet::setBasic(resultKeys);
+		return resultKeys;
 	}
 	else
 	{
 		KeySet conflictSet = result.getConflictSet();
-		QStringList conflicts;
-		conflictSet.rewind();
-		Key current;
-
-		while ((current = conflictSet.next()))
-		{
-			QString ourConflict = QString::fromStdString(current.getMeta<string>("conflict/operation/our"));
-			QString theirConflict = QString::fromStdString(current.getMeta<string>("conflict/operation/their"));
-
-			conflicts.append(QString::fromStdString(current.getName()));
-			conflicts.append("Ours: " + ourConflict + ", Theirs " + theirConflict);
-			conflicts.append("\n");
-		}
-
-		emit showMessage(tr("Error"), tr("Synchronizing failed, conflicts occured."), conflicts.join("\n"));
-		return;
+		QStringList conflicts = getConflicts(conflictSet);
+		throw conflicts;
 	}
+}
+}
+
+void TreeViewModel::synchronize()
+{
+	KeySet ours = collectCurrentKeySet();
 
 	try
 	{
-		kdb.set(resultKeys, root);
+		// write our config
+		m_kdb.set(ours, m_root);
+		// update our config (if no conflict)
+		m_kdb.get(ours, m_root);
+
+		GUIBasicKeySet::setBasic(ours);
+		createNewNodes(ours);
 	}
-	catch (KDBException const& e)
+	catch (KDBException const&)
 	{
-		emit showMessage(tr("Error"), tr("Synchronizing failed, could not write to configuration."), e.what());
-		return;
+		try
+		{
+			KeySet renew;
+
+			KeySet result = handleConflict(ours);
+
+			// bring our database also to situation where it can be reset
+			m_kdb.get(renew, m_root);
+
+			/* TODO: should be added to fix race condition, currently not possible
+			   because some plugins prevent kdb.get() from returning 0
+			if (m_kdb.get(renew, m_root) == 0)
+			{
+			} else {
+				emit showMessage(tr("Error"), tr("Database changed during merging."), "");
+			}
+			*/
+
+			// TODO: will rewrite everything because of current limitation in merger
+			m_kdb.set(result, m_root);
+			createNewNodes(result);
+		}
+		catch (KDBException const& e)
+		{
+			emit showMessage(tr("Error"), tr("Synchronizing failed, could not write merged configuration."), e.what());
+		}
+		catch (QStringList const& conflicts)
+		{
+			emit showMessage(tr("Error"), tr("Synchronizing failed, conflicts occured."), conflicts.join("\n"));
+		}
 	}
-
-	GUIBasicKeySet::setBasic(resultKeys);
-
-	createNewNodes(resultKeys);
 }
 
 void TreeViewModel::clearMetaModel()
@@ -643,7 +723,7 @@ QString TreeViewModel::getCurrentArrayNo() const
 	}
 
 	if(max){
-		Key k = max->getKey().dup();
+		Key k = max->getKey();
 		ckdb::elektraArrayIncName(k.getKey());
 		return QString::fromStdString(k.getBaseName());
 	}
